Learn R Programming

birp (version 0.0.5)

.addToList.birp: Function to convert an argument to a string and add it to a list if necessary

Description

Function to convert an argument to a string and add it to a list if necessary

Usage

.addToList.birp(options, name, x)

Value

An updated list options

Arguments

options

A list where x should be added to

name

A string specifying the name of the argument

x

An R object to be added to the list