Learn R Programming

birp (version 0.0.5)

.calculateRho.birp: Function to calculate rho

Description

Function to calculate rho

Usage

.calculateRho.birp(times, times_of_change)

Value

A numeric matrix containing rho for each time point and epoch

Arguments

times

An integer or numeric vector with time points

times_of_change

An integer or numeric vector with times of change