Learn R Programming

birp (version 0.0.5)

.getDataAllMethods.birp_data: This function reads data for all methods into a list

Description

This function reads data for all methods into a list

Usage

.getDataAllMethods.birp_data(out, what, res)

Value

An instance of birp_data

Arguments

out

A string corresponding to the output prefix

res

A list of dataframes from Rcpp