Learn R Programming

birp (version 0.0.5)

.getEpochStarts.birp: Function to get the start of each epoch, including for a hypothetical epoch after the last epoch

Description

Function to get the start of each epoch, including for a hypothetical epoch after the last epoch

Usage

.getEpochStarts.birp(times, times_of_change)

Value

An integer or numeric vector with starting points for each epoch

Arguments

times

An integer or numeric vector with time points

times_of_change

An integer or numeric vector with times of change