Learn R Programming

birp (version 0.0.5)

.getLabelGamma.birp: Function to generate a nice axis label with greek gamma and subscript

Description

Function to generate a nice axis label with greek gamma and subscript

Usage

.getLabelGamma.birp(x, index)

Value

A string

Arguments

index

The index in the subscript