Learn R Programming

birp (version 0.0.5)

.openPosteriorPlot.birp: Function to open an empty plot for plotting the posterior probabilities

Description

Function to open an empty plot for plotting the posterior probabilities

Usage

.openPosteriorPlot.birp(
  xlim,
  ylim,
  xlab,
  ylab,
  shadingIncrease,
  shadingDecrease,
  lineAtZero,
  ...
)

Value

No return value, called for side effects.

Arguments

xlim

The x-limits (x1, x2) of the plot

ylim

The y-limits (y1, y2) of the plot

xlab

Name of x axis

ylab

Name of y axis

shadingIncrease

Shading color for the range gamma > 0. If NA, shading is omitted

shadingDecrease

Shading color for the range gamma < 0. If NA, shading is omitted

lineAtZero

If TRUE, adds a dashed line indicating 0.