Learn R Programming

birp (version 0.0.5)

birp_from_command_line: Create a birp Object from Command-Line Output Files

Description

This function creates a birp object by reading the output files generated by the command-line version of the birp tool.

Usage

birp_from_command_line(path)

Value

An object of type birp containing MCMC results and model estimates read from files.

Arguments

path

Character string specifying the directory path containing all birp output files.

Examples

Run this code
est <- birp_from_command_line(file.path(system.file("extdata", package = "birp")))

Run the code above in your browser using DataLab