Learn R Programming

birp (version 0.0.5)

print.birp: Print a birp object

Description

Prints a summary of the estimated parameters from a birp model.

Usage

# S3 method for birp
print(x, ...)

Value

Invisibly returns the input x, called for side effects.

Arguments

x

A birp object.

...

Additional arguments passed to internal methods (currently unused).

See Also

birp

Examples

Run this code
data <- simulate_birp()
est <- birp(data)
print(est)

Run the code above in your browser using DataLab