Learn R Programming

birp (version 0.0.5)

summary.birp: Summary method for birp objects

Description

Provides a printed summary of model estimates for a birp object.

Usage

# S3 method for birp
summary(object, ...)

Value

Invisibly returns the input object, called for side effects.

Arguments

object

A birp object.

...

Additional arguments passed to print.birp.

See Also

birp

Examples

Run this code
data <- simulate_birp()
est <- birp(data)
summary(est)

Run the code above in your browser using DataLab