.addTextSingleGamma.birp: Function to add text box to plot denoting P(gamma > 0 | n) or P(gamma < 0 | n) for single gammas
Description
Function to add text box to plot denoting P(gamma > 0 | n) or P(gamma < 0 | n) for single gammas
Usage
.addTextSingleGamma.birp(x)
Value
No return value, called for side effects.