Function to check if a file exists and generate error message if it was not found
.checkFile.birp(
path,
files,
patterns,
allowMultiMatch = FALSE,
sep = "\t",
mustExist = TRUE
)A string denoting the filename(s)
A file path
A vector of character strings corresponding to file names found in the path
A vector of patterns to search for within 'files'
Logical. If TRUE, multiple matches are allowed
The field separator character of the input file
Logical. If TRUE, an exception is raised if the file does not exist