Function to create an object of type birp
.createObjBirp.birp(
data,
meanVar,
trace,
gamma,
timepoints,
timesOfChange,
BACI,
CI_groups,
state
)An object of type birp
An object of type birp_data, corresponding to filtered data used for inference
A data frame containing the posterior mean and variance of all parameters
A data frame containing the MCMC trace of all parameters
A data frame containing the posterior probabilities regarding gamma
An integer vector containing the timepoints at which counts were obtained
A numeric or integer vector specifying the times of change
A matrix specifying the BACI configuration. Each row of the matrix corresponds to a control/intervention group, and each column to an epoch. The very first column specifies the name of the control-intervention group and must match the groups specified in data. The values of the matrix specify which gamma to use for each group and epoch. E.g. BACI = matrix(c("A", "B", 1, 1, 1, 2), nrow = 2) corresponds to a canonical BACI design where the first row represents the control group (A) and the second row represents the intervention group (B)
A character vector specifying the names of the control-intervention (CI) group
A data frame containing the posterior mean values of all parameters inferred by birp