Function to get the start of each epoch, including for a hypothetical epoch after the last epoch
.getEpochStarts.birp(times, times_of_change)An integer or numeric vector with starting points for each epoch
An integer or numeric vector with time points
An integer or numeric vector with times of change