.getLabelGamma.birp: Function to generate a nice axis label with greek gamma and subscript
Description
Function to generate a nice axis label with greek gamma and subscript
Usage
.getLabelGamma.birp(x, index)
Arguments
- index
The index in the subscript