Function to open a file and generate error message if it was not found
.openFile.birp(
path,
files,
patterns,
sep = "\t",
header = TRUE,
mustExist = TRUE
)A file connection.
A file path.
A vector of character strings corresponding to file names found in the path.
A vector of patterns to search for within 'files'.
The field separator character of the input file
Logical. If TRUE, an exception is raised if the file does not exist