powered by
Constructs a 'birp_data' object from one or more input files, each representing data for a different method.
birp_data_from_file(filenames, method_names = NA, sep = ",")
An object of type birp_data
A character vector of file paths. Each file must contain a data frame with the columns 'timepoint', 'location', 'counts', 'effort' and 'CI_group'.
Optional vector of method names corresponding to the input files. If not provided, names are inferred from the file names.
The field separator used in the files (default is comma).
dir <- system.file("extdata", package = "birp") filenames <- file.path(dir, "birp_Method_1_simulated_counts.txt") data <- birp_data_from_file(filenames = filenames, sep = "\t")
Run the code above in your browser using DataLab