powered by
This function creates a birp object by reading the output files generated by the command-line version of the birp tool.
birp_from_command_line(path)
An object of type birp containing MCMC results and model estimates read from files.
birp
Character string specifying the directory path containing all birp output files.
est <- birp_from_command_line(file.path(system.file("extdata", package = "birp")))
Run the code above in your browser using DataLab