powered by
Prints a summary of the estimated parameters from a birp model.
birp
# S3 method for birp print(x, ...)
Invisibly returns the input x, called for side effects.
x
A birp object.
Additional arguments passed to internal methods (currently unused).
data <- simulate_birp() est <- birp(data) print(est)
Run the code above in your browser using DataLab