print.birp_data: Print a birp_data object
Prints a summary of a birp_data object, including the number of methods, locations, control-intervention (CI) groups, and timepoints, as well as the names or identifiers for each.
Description
Print a birp_data object
Prints a summary of a birp_data object, including the number of methods, locations, control-intervention (CI) groups, and timepoints, as well as the names or identifiers for each.
Usage
# S3 method for birp_data
print(x, ...)
Value
No return value; this function is called for its side effects (printing to console).