powered by
Provides a printed summary of model estimates for a birp object.
birp
# S3 method for birp summary(object, ...)
Invisibly returns the input object, called for side effects.
object
A birp object.
Additional arguments passed to print.birp.
print.birp
data <- simulate_birp() est <- birp(data) summary(est)
Run the code above in your browser using DataLab